@@ -3,7 +3,7 @@
 //! Notably, it uses a different round number and uses a "tweaked" CBC mode.
 
 mod stream_ext;
-mod tc_tea;
+mod tc_tea_public;
 mod tc_tea_internal;
 
-pub use tc_tea::*;
+pub use tc_tea_public::*;
